@@ -1,13 +1,13 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2012-08-06
  * @brief  Plugins config widget.
  *
- * @author Copyright (C) 2004-2017 by Gilles Caulier
+ * @author Copyright (C) 2004-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2012      by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
@@ -71,7 +71,7 @@ public:
 
     /** Select all plugins in the list.
      */
-    void selectAll();
+    void selectAll() Q_DECL_OVERRIDE;
 
     /** Clear all selected plugins in the list.
      */
